from setuptools import setup

setup(name='OM_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions'],
      author = "Udacity",
      zip_safe=False)
